UmaBucket

Struct UmaBucket 

#[repr(C)]
pub struct UmaBucket { pub hdr: BucketHdr, pub items: [*mut u8], }
Implementation of uma_bucket structure.

Safety

Adding more fields into this struct without knowing how it work can cause undefined behavior in some places.

Fields

hdr: BucketHdritems: [*mut u8]